# ⚙️ Installation

## 🥹 EZ way

```bash
$ pip install perfassess
```

## 😩 From source
### 👬 Cloning the repository

You can clone the repository using `HTTPS`:

```bash
$ git clone https://github.com/FilouPlains/perfassess.git
```

or using `SSH`:

```bash
$ git clone git@github.com:FilouPlains/perfassess.git
```

Then go to the `📁 perfassess/` directory:

```bash
$ cd perfassess
```

**All next commands are assuming that you are in the `📁 perfassess/` directory. This directory will be name as `📁 ./`.**

### 🐍📦 Installing with pip

Simply launch this command in the `📁 ./` directory:

```bash
$ python3 -m pip install .
```

**You are now able to launch the program!**
